You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by an...@apache.org on 2012/09/21 01:18:25 UTC

android commit: updating windows create script test

Updated Branches:
  refs/heads/master c206ac033 -> 79682f5d5


updating windows create script test


Project: http://git-wip-us.apache.org/repos/asf/incubator-cordova-android/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-cordova-android/commit/79682f5d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-cordova-android/tree/79682f5d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-cordova-android/diff/79682f5d

Branch: refs/heads/master
Commit: 79682f5d523c0c985ad6c010fbbb37d333fc3765
Parents: c206ac0
Author: Anis Kadri <an...@gmail.com>
Authored: Thu Sep 20 16:17:59 2012 -0700
Committer: Anis Kadri <an...@gmail.com>
Committed: Thu Sep 20 16:17:59 2012 -0700

----------------------------------------------------------------------
 bin/tests/test_create_win.js |   11 +++--------
 1 files changed, 3 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-cordova-android/blob/79682f5d/bin/tests/test_create_win.js
----------------------------------------------------------------------
diff --git a/bin/tests/test_create_win.js b/bin/tests/test_create_win.js
index 238e916..c634a94 100644
--- a/bin/tests/test_create_win.js
+++ b/bin/tests/test_create_win.js
@@ -88,14 +88,9 @@ create_project.on('exit', function(code) {
         // TODO check that package name and activity name were substituted properly
     });
    
-    // make sure plugins.xml was added
-    path.exists(util.format('%s/res/xml/plugins.xml', project_path), function(exists) {
-        assert(exists, 'plugins.xml did not get created');
-    });
-    
-    // make sure cordova.xml was added
-    path.exists(util.format('%s/res/xml/cordova.xml', project_path), function(exists) {
-        assert(exists, 'plugins.xml did not get created');
+    // make sure config.xml was added
+    path.exists(util.format('%s/res/xml/config.xml', project_path), function(exists) {
+        assert(exists, 'config.xml did not get created');
     });
     
     // make sure cordova.jar was added